@@ -9,6 +9,8 @@ from mariadb_kernel.maria_magics.lsmagic import LSMagic
 from mariadb_kernel.maria_magics.maria_magic import MariaMagic
 from mariadb_kernel.maria_magics.bar import Bar
 from mariadb_kernel.maria_magics.pie import Pie
+from mariadb_kernel.maria_magics.delimiter import Delimiter
+
 
 def get():
     return {
@@ -16,6 +18,6 @@ def get():
         "bar": Bar,
         "pie": Pie,
         "df": DF,
-        "lsmagic": LSMagic
+        "lsmagic": LSMagic,
+        "delimiter": Delimiter,
     }
-
