@@ -5,9 +5,18 @@ from pathlib import Path
 from subprocess import check_output
 from ..mariadb_server import MariaDBServer
 
+
+def cleanup_server_setup():
+    cnfpath = Path.home().joinpath(".my.cnf")
+    backup = Path.home().joinpath("mycnf_backup")
+    if backup.exists():
+        backup.replace(cnfpath)
+    shutil.rmtree("/tmp/datadir-test")
+
+
 @pytest.fixture(scope="session", autouse=True)
 def server_setup():
-    cfg="""
+    cfg = """
     [client-server]
     socket=/tmp/mysql-dbug.sock
     port=3306
@@ -20,9 +29,9 @@ def server_setup():
     skip_log_error
     """
 
-    cnfpath = Path.home().joinpath('.my.cnf')
+    cnfpath = Path.home().joinpath(".my.cnf")
     if cnfpath.exists():
-        backup = Path.home().joinpath('mycnf_backup')
+        backup = Path.home().joinpath("mycnf_backup")
         cnfpath.rename(backup)
 
     with cnfpath.open("w") as f:
@@ -30,20 +39,27 @@ def server_setup():
 
     os.mkdir("/tmp/datadir-test")
 
-    check_output(["mysql_install_db",
-                  "--datadir=/tmp/datadir-test",
-                  "--auth-root-authentication-method=normal"])
+    try:
+        check_output(
+            [
+                "mysql_install_db",
+                "--datadir=/tmp/datadir-test",
+                "--auth-root-authentication-method=normal",
+            ]
+        )
+    except:
+        cleanup_server_setup()
+        raise
+
     yield
 
-    cnfpath = Path.home().joinpath('.my.cnf')
-    backup = Path.home().joinpath('mycnf_backup')
-    if backup.exists():
-        backup.replace(cnfpath)
-    shutil.rmtree('/tmp/datadir-test')
+    cleanup_server_setup()
+
 
 @pytest.fixture
 def mariadb_server():
     server = None
+
     def _server(log, config):
         nonlocal server
         server = MariaDBServer(log, config)
@@ -54,8 +70,7 @@ def mariadb_server():
 
     server.stop()
 
+
 @pytest.fixture(params=["line", "bar", "pie", "df", "lsmagic"])
 def magic_cmd(request):
     return request.param
-
-
